Learn R Programming

bayeslongitudinal (version 0.1.0)

bloques2: bloques arma (1,1)

Description

Build a block diagonal matrix with structure ARMA(1,1)

Usage

bloques2(s, r, g, t, n)

Arguments

s

Numerical value indicating global standard deviation of the matrix

r

Numerical value indicating the first parameter rho correlation of individuals

g

Numerical value indicating the second parameter phi correlation of individuals

t

Numerical value indicating number of times when observations are repeated

n

Numerical value indicating number of individuals

Value

A diagonal block matrix with structure ARMA(1,1)

References

Nu<U+00F1>ez A. and Zimmerman D. 2001. Modelaci<U+00F3>n de datos longitudinales con estructuras de covarianza no estacionarias: Modelo de coeficientes aleatorios frente a modelos alternativos. Questio. 2001. 25.

Examples

Run this code
# NOT RUN {
bloques2(2,.5,.8,10,2)
# }

Run the code above in your browser using DataLab