Build a block diagonal matrix with compound symmetry structure
Usage
bloques3(s, r, t, n)
Arguments
s
Numerical value indicating global standard deviation of the matrix
r
Numerical value indicating correlation of individuals
t
Numerical value indicating number of times when observations are repeated
n
Numerical value indicating number of individuals
Value
A diagonal block matrix with compound symmetry structure
References
Nu<U+00F1>ez A. and Zimmerman D. 2001. Modelaci<U+00F3>n de datos longitudinales con estructuras de covarianza no estacionarias: Modelo de coeficientes aleatorios frente a modelos alternativos. Questio. 2001. 25.